@@ -5,6 +5,7 @@ Created on 2021-08-06
 '''
 from python_on_whales import docker
 import os
+import platform
 import datetime
 import time
 import secrets
@@ -71,6 +72,7 @@ class DockerApplication(object):
         self.smwVersion=smwVersion
         self.underscoreVersion=version.replace(".","_")
         self.shortVersion=self.getShortVersion()
+        # container names
         # branch as need for git clone e.g. https://gerrit.wikimedia.org/g/mediawiki/extensions/MagicNoCache
         self.branch=f"REL{self.getShortVersion('_')}"
         self.mariaDBVersion=mariaDBVersion
@@ -121,6 +123,10 @@ class DockerApplication(object):
         '''
         return f"{self.name}_{self.version}"
     
+    def getContainerName(self,kind:str,separator:str):
+        containerName=f"mw{self.underscoreVersion}{separator}{kind}{separator}1"
+        return containerName
+    
     def getContainers(self):
         '''
         get my containers
@@ -128,12 +134,15 @@ class DockerApplication(object):
         self.dbContainer=None
         self.mwContainer=None
         containerMap=DockerMap.getContainerMap()
-        dbContainerName=f"mw{self.underscoreVersion}_db_1"
-        mwContainerName=f"mw{self.underscoreVersion}_mw_1"
-        if dbContainerName in containerMap:
-            self.dbContainer=containerMap[dbContainerName]
-        if mwContainerName in containerMap:
-            self.mwContainer=containerMap[mwContainerName]      
+        for separator in ["-","_"]:
+            dbContainerName=self.getContainerName("db", separator)
+            mwContainerName=self.getContainerName("mw", separator)
+            if dbContainerName in containerMap:
+                self.dbContainerName=dbContainerName
+                self.dbContainer=containerMap[self.dbContainerName]
+            if mwContainerName in containerMap:
+                self.mwContainerName=mwContainerName
+                self.mwContainer=containerMap[self.mwContainerName]      
             
     def getJinjaEnv(self):
         '''
@@ -204,9 +213,14 @@ class DockerApplication(object):
         execute the given command
         '''
         if self.mwContainer:
+            if self.verbose:
+                print(f"Executing docker command {command}")
             docker.execute(container=self.mwContainer,command=command)
         else:
-            raise Exception(f"no mediawiki Container for {self.name}")
+            mwContainerNameDash=self.getContainerName("mw", "-")
+            mwContainerNameUnderscore=self.getContainerName("mw", "_")
+            errMsg=f"no mediawiki Container {mwContainerNameDash} or {mwContainerNameUnderscore} for {self.name} activated by docker compose\n- you might want to check the separator {self.mw_container_name_separator} for your platform {platform.system()}"
+            raise Exception(f"{errMsg}")
     
     def close(self):
         self.dbClose()
@@ -250,7 +264,8 @@ class DockerApplication(object):
                                  connection_timeout=timeout)
         
             except Error as e :
-                print (f"Connection to {self.database} on {self.host} with user {self.dbUser} failed error: {str(e)}" )
+                errMsg=str(e)
+                print (f"Connection to {self.database} on {self.host} with user {self.dbUser} failed error: {errMsg}" )
         return self.dbConn
     
     def doCheckDBConnection(self,timeout:int=10)->bool:
