@@ -5,5 +5,5 @@ cd /var/www/html/extensions
 {% for extension in extensions %}
 # {{ extension.name }}
 # {{ extension.url }}
-{{ extension.asScript() | safe }}
-{{ extension.localSettings }}{% endfor %}
\ No newline at end of file
+{{ extension.asScript(branch) | safe }}
+{% endfor %}
\ No newline at end of file
